
/*
===============================================================================
                    EntitySpaces Studio by EntitySpaces, LLC
             Persistence Layer and Business Objects for Microsoft .NET
             EntitySpaces(TM) is a legal trademark of EntitySpaces, LLC
                          http://www.entityspaces.net
===============================================================================
EntitySpaces Version : 2012.1.0930.0
EntitySpaces Driver  : SQL
===============================================================================
*/

using System;
using System.Collections;
using System.Collections.Generic;
using System.Diagnostics;
using System.Text;
using System.Linq;
using System.Data;
using System.ComponentModel;
using System.Xml.Serialization;
using System.Runtime.Serialization;

using EntitySpaces.Core;
using EntitySpaces.Interfaces;
using EntitySpaces.DynamicQuery;


using DotNetNuke.Framework.Providers;


namespace DNNspot.Tabs.DataModel
{
	/// <summary>
	/// Encapsulates the 'DNNspot_Tabs_Panes' table
	/// </summary>

    [DebuggerDisplay("Data = {Debug}")]
	[Serializable]
	[DataContract]
	[KnownType(typeof(Pane))]	
	[XmlType("Pane")]
	public partial class Pane : esPane
	{	
		[DebuggerBrowsable(DebuggerBrowsableState.RootHidden | DebuggerBrowsableState.Never)]
		protected override esEntityDebuggerView[] Debug
		{
			get { return base.Debug; }
		}

		override public esEntity CreateInstance()
		{
			return new Pane();
		}
		
		#region Static Quick Access Methods
		static public void Delete(System.Int32 id)
		{
			var obj = new Pane();
			obj.Id = id;
			obj.AcceptChanges();
			obj.MarkAsDeleted();
			obj.Save();
		}

	    static public void Delete(System.Int32 id, esSqlAccessType sqlAccessType)
		{
			var obj = new Pane();
			obj.Id = id;
			obj.AcceptChanges();
			obj.MarkAsDeleted();
			obj.Save(sqlAccessType);
		}
		#endregion

		
					
		
	
	}



    [DebuggerDisplay("Count = {Count}")]
	[Serializable]
	[CollectionDataContract]
	[XmlType("PaneCollection")]
	public partial class PaneCollection : esPaneCollection, IEnumerable<Pane>
	{
		public Pane FindByPrimaryKey(System.Int32 id)
		{
			return this.SingleOrDefault(e => e.Id == id);
		}

		
		
		#region WCF Service Class
		
		[DataContract]
		[KnownType(typeof(Pane))]
		public class PaneCollectionWCFPacket : esCollectionWCFPacket<PaneCollection>
		{
			public static implicit operator PaneCollection(PaneCollectionWCFPacket packet)
			{
				return packet.Collection;
			}

			public static implicit operator PaneCollectionWCFPacket(PaneCollection collection)
			{
				return new PaneCollectionWCFPacket() { Collection = collection };
			}
		}
		
		#endregion
		
				
	}



    [DebuggerDisplay("Query = {Parse()}")]
	[Serializable]	
	public partial class PaneQuery : esPaneQuery
	{
		public PaneQuery(string joinAlias)
		{
			this.es.JoinAlias = joinAlias;
		}	

		override protected string GetQueryName()
		{
			return "PaneQuery";
		}
		
					
	
		#region Explicit Casts
		
		public static explicit operator string(PaneQuery query)
		{
			return PaneQuery.SerializeHelper.ToXml(query);
		}

		public static explicit operator PaneQuery(string query)
		{
			return (PaneQuery)PaneQuery.SerializeHelper.FromXml(query, typeof(PaneQuery));
		}
		
		#endregion		
	}

	[DataContract]
	[Serializable]
	abstract public partial class esPane : esEntity
	{
		public esPane()
		{

		}
		
		#region LoadByPrimaryKey
		public virtual bool LoadByPrimaryKey(System.Int32 id)
		{
			if(this.es.Connection.SqlAccessType == esSqlAccessType.DynamicSQL)
				return LoadByPrimaryKeyDynamic(id);
			else
				return LoadByPrimaryKeyStoredProcedure(id);
		}

		public virtual bool LoadByPrimaryKey(esSqlAccessType sqlAccessType, System.Int32 id)
		{
			if (sqlAccessType == esSqlAccessType.DynamicSQL)
				return LoadByPrimaryKeyDynamic(id);
			else
				return LoadByPrimaryKeyStoredProcedure(id);
		}

		private bool LoadByPrimaryKeyDynamic(System.Int32 id)
		{
			PaneQuery query = new PaneQuery();
			query.Where(query.Id == id);
			return this.Load(query);
		}

		private bool LoadByPrimaryKeyStoredProcedure(System.Int32 id)
		{
			esParameters parms = new esParameters();
			parms.Add("Id", id);
			return this.Load(esQueryType.StoredProcedure, this.es.spLoadByPrimaryKey, parms);
		}
		#endregion
		
		#region Properties
		
		
		
		/// <summary>
		/// Maps to DNNspot_Tabs_Panes.ID
		/// </summary>
		[DataMember(EmitDefaultValue=false)]
		virtual public System.Int32? Id
		{
			get
			{
				return base.GetSystemInt32(PaneMetadata.ColumnNames.Id);
			}
			
			set
			{
				if(base.SetSystemInt32(PaneMetadata.ColumnNames.Id, value))
				{
					OnPropertyChanged(PaneMetadata.PropertyNames.Id);
				}
			}
		}		
		
		/// <summary>
		/// Maps to DNNspot_Tabs_Panes.PortalID
		/// </summary>
		[DataMember(EmitDefaultValue=false)]
		virtual public System.Int32? PortalID
		{
			get
			{
				return base.GetSystemInt32(PaneMetadata.ColumnNames.PortalID);
			}
			
			set
			{
				if(base.SetSystemInt32(PaneMetadata.ColumnNames.PortalID, value))
				{
					OnPropertyChanged(PaneMetadata.PropertyNames.PortalID);
				}
			}
		}		
		
		/// <summary>
		/// Maps to DNNspot_Tabs_Panes.ModuleID
		/// </summary>
		[DataMember(EmitDefaultValue=false)]
		virtual public System.Int32? ModuleID
		{
			get
			{
				return base.GetSystemInt32(PaneMetadata.ColumnNames.ModuleID);
			}
			
			set
			{
				if(base.SetSystemInt32(PaneMetadata.ColumnNames.ModuleID, value))
				{
					OnPropertyChanged(PaneMetadata.PropertyNames.ModuleID);
				}
			}
		}		
		
		/// <summary>
		/// Maps to DNNspot_Tabs_Panes.Title
		/// </summary>
		[DataMember(EmitDefaultValue=false)]
		virtual public System.String Title
		{
			get
			{
				return base.GetSystemString(PaneMetadata.ColumnNames.Title);
			}
			
			set
			{
				if(base.SetSystemString(PaneMetadata.ColumnNames.Title, value))
				{
					OnPropertyChanged(PaneMetadata.PropertyNames.Title);
				}
			}
		}		
		
		/// <summary>
		/// Maps to DNNspot_Tabs_Panes.Body
		/// </summary>
		[DataMember(EmitDefaultValue=false)]
		virtual public System.String Body
		{
			get
			{
				return base.GetSystemString(PaneMetadata.ColumnNames.Body);
			}
			
			set
			{
				if(base.SetSystemString(PaneMetadata.ColumnNames.Body, value))
				{
					OnPropertyChanged(PaneMetadata.PropertyNames.Body);
				}
			}
		}		
		
		/// <summary>
		/// Maps to DNNspot_Tabs_Panes.IsVisible
		/// </summary>
		[DataMember(EmitDefaultValue=false)]
		virtual public System.Boolean? IsVisible
		{
			get
			{
				return base.GetSystemBoolean(PaneMetadata.ColumnNames.IsVisible);
			}
			
			set
			{
				if(base.SetSystemBoolean(PaneMetadata.ColumnNames.IsVisible, value))
				{
					OnPropertyChanged(PaneMetadata.PropertyNames.IsVisible);
				}
			}
		}		
		
		/// <summary>
		/// Maps to DNNspot_Tabs_Panes.DisplayOrder
		/// </summary>
		[DataMember(EmitDefaultValue=false)]
		virtual public System.Int32? DisplayOrder
		{
			get
			{
				return base.GetSystemInt32(PaneMetadata.ColumnNames.DisplayOrder);
			}
			
			set
			{
				if(base.SetSystemInt32(PaneMetadata.ColumnNames.DisplayOrder, value))
				{
					OnPropertyChanged(PaneMetadata.PropertyNames.DisplayOrder);
				}
			}
		}		
		
		/// <summary>
		/// Maps to DNNspot_Tabs_Panes.CreatedDate
		/// </summary>
		[DataMember(EmitDefaultValue=false)]
		virtual public System.DateTime? CreatedDate
		{
			get
			{
				return base.GetSystemDateTime(PaneMetadata.ColumnNames.CreatedDate);
			}
			
			set
			{
				if(base.SetSystemDateTime(PaneMetadata.ColumnNames.CreatedDate, value))
				{
					OnPropertyChanged(PaneMetadata.PropertyNames.CreatedDate);
				}
			}
		}		
		
		/// <summary>
		/// Maps to DNNspot_Tabs_Panes.ModifiedDate
		/// </summary>
		[DataMember(EmitDefaultValue=false)]
		virtual public System.DateTime? ModifiedDate
		{
			get
			{
				return base.GetSystemDateTime(PaneMetadata.ColumnNames.ModifiedDate);
			}
			
			set
			{
				if(base.SetSystemDateTime(PaneMetadata.ColumnNames.ModifiedDate, value))
				{
					OnPropertyChanged(PaneMetadata.PropertyNames.ModifiedDate);
				}
			}
		}		
		
		#endregion	

		#region .str() Properties
		
		public override void SetProperties(IDictionary values)
		{
			foreach (string propertyName in values.Keys)
			{
				this.SetProperty(propertyName, values[propertyName]);
			}
		}
		
		public override void SetProperty(string name, object value)
		{
			esColumnMetadata col = this.Meta.Columns.FindByPropertyName(name);
			if (col != null)
			{
				if(value == null || value is System.String)
				{				
					// Use the strongly typed property
					switch (name)
					{							
						case "Id": this.str().Id = (string)value; break;							
						case "PortalID": this.str().PortalID = (string)value; break;							
						case "ModuleID": this.str().ModuleID = (string)value; break;							
						case "Title": this.str().Title = (string)value; break;							
						case "Body": this.str().Body = (string)value; break;							
						case "IsVisible": this.str().IsVisible = (string)value; break;							
						case "DisplayOrder": this.str().DisplayOrder = (string)value; break;							
						case "CreatedDate": this.str().CreatedDate = (string)value; break;							
						case "ModifiedDate": this.str().ModifiedDate = (string)value; break;
					}
				}
				else
				{
					switch (name)
					{	
						case "Id":
						
							if (value == null || value is System.Int32)
								this.Id = (System.Int32?)value;
								OnPropertyChanged(PaneMetadata.PropertyNames.Id);
							break;
						
						case "PortalID":
						
							if (value == null || value is System.Int32)
								this.PortalID = (System.Int32?)value;
								OnPropertyChanged(PaneMetadata.PropertyNames.PortalID);
							break;
						
						case "ModuleID":
						
							if (value == null || value is System.Int32)
								this.ModuleID = (System.Int32?)value;
								OnPropertyChanged(PaneMetadata.PropertyNames.ModuleID);
							break;
						
						case "IsVisible":
						
							if (value == null || value is System.Boolean)
								this.IsVisible = (System.Boolean?)value;
								OnPropertyChanged(PaneMetadata.PropertyNames.IsVisible);
							break;
						
						case "DisplayOrder":
						
							if (value == null || value is System.Int32)
								this.DisplayOrder = (System.Int32?)value;
								OnPropertyChanged(PaneMetadata.PropertyNames.DisplayOrder);
							break;
						
						case "CreatedDate":
						
							if (value == null || value is System.DateTime)
								this.CreatedDate = (System.DateTime?)value;
								OnPropertyChanged(PaneMetadata.PropertyNames.CreatedDate);
							break;
						
						case "ModifiedDate":
						
							if (value == null || value is System.DateTime)
								this.ModifiedDate = (System.DateTime?)value;
								OnPropertyChanged(PaneMetadata.PropertyNames.ModifiedDate);
							break;
					

						default:
							break;
					}
				}
			}
            else if (this.ContainsColumn(name))
            {
                this.SetColumn(name, value);
            }
			else
			{
				throw new Exception("SetProperty Error: '" + name + "' not found");
			}
		}		

		public esStrings str()
		{
			if (esstrings == null)
			{
				esstrings = new esStrings(this);
			}
			return esstrings;
		}

		sealed public class esStrings
		{
			public esStrings(esPane entity)
			{
				this.entity = entity;
			}
			
	
			public System.String Id
			{
				get
				{
					System.Int32? data = entity.Id;
					return (data == null) ? String.Empty : Convert.ToString(data);
				}

				set
				{
					if (value == null || value.Length == 0) entity.Id = null;
					else entity.Id = Convert.ToInt32(value);
				}
			}
				
			public System.String PortalID
			{
				get
				{
					System.Int32? data = entity.PortalID;
					return (data == null) ? String.Empty : Convert.ToString(data);
				}

				set
				{
					if (value == null || value.Length == 0) entity.PortalID = null;
					else entity.PortalID = Convert.ToInt32(value);
				}
			}
				
			public System.String ModuleID
			{
				get
				{
					System.Int32? data = entity.ModuleID;
					return (data == null) ? String.Empty : Convert.ToString(data);
				}

				set
				{
					if (value == null || value.Length == 0) entity.ModuleID = null;
					else entity.ModuleID = Convert.ToInt32(value);
				}
			}
				
			public System.String Title
			{
				get
				{
					System.String data = entity.Title;
					return (data == null) ? String.Empty : Convert.ToString(data);
				}

				set
				{
					if (value == null || value.Length == 0) entity.Title = null;
					else entity.Title = Convert.ToString(value);
				}
			}
				
			public System.String Body
			{
				get
				{
					System.String data = entity.Body;
					return (data == null) ? String.Empty : Convert.ToString(data);
				}

				set
				{
					if (value == null || value.Length == 0) entity.Body = null;
					else entity.Body = Convert.ToString(value);
				}
			}
				
			public System.String IsVisible
			{
				get
				{
					System.Boolean? data = entity.IsVisible;
					return (data == null) ? String.Empty : Convert.ToString(data);
				}

				set
				{
					if (value == null || value.Length == 0) entity.IsVisible = null;
					else entity.IsVisible = Convert.ToBoolean(value);
				}
			}
				
			public System.String DisplayOrder
			{
				get
				{
					System.Int32? data = entity.DisplayOrder;
					return (data == null) ? String.Empty : Convert.ToString(data);
				}

				set
				{
					if (value == null || value.Length == 0) entity.DisplayOrder = null;
					else entity.DisplayOrder = Convert.ToInt32(value);
				}
			}
				
			public System.String CreatedDate
			{
				get
				{
					System.DateTime? data = entity.CreatedDate;
					return (data == null) ? String.Empty : Convert.ToString(data);
				}

				set
				{
					if (value == null || value.Length == 0) entity.CreatedDate = null;
					else entity.CreatedDate = Convert.ToDateTime(value);
				}
			}
				
			public System.String ModifiedDate
			{
				get
				{
					System.DateTime? data = entity.ModifiedDate;
					return (data == null) ? String.Empty : Convert.ToString(data);
				}

				set
				{
					if (value == null || value.Length == 0) entity.ModifiedDate = null;
					else entity.ModifiedDate = Convert.ToDateTime(value);
				}
			}
			

			private esPane entity;
		}
		
		[NonSerialized]
		private esStrings esstrings;		
		
		#endregion
		
		#region Housekeeping methods

		override protected IMetadata Meta
		{
			get
			{
				return PaneMetadata.Meta();
			}
		}

		#endregion		
		
		#region Query Logic

		public PaneQuery Query
		{
			get
			{
				if (this.query == null)
				{
					this.query = new PaneQuery();
					InitQuery(this.query);
				}

				return this.query;
			}
		}

		public bool Load(PaneQuery query)
		{
			this.query = query;
			InitQuery(this.query);
			return this.Query.Load();
		}
		
		protected void InitQuery(PaneQuery query)
		{
			query.OnLoadDelegate = this.OnQueryLoaded;
			
			if (!query.es2.HasConnection)
			{
				query.es2.Connection = ((IEntity)this).Connection;
			}			
		}

		#endregion
		
        [IgnoreDataMember]
		private PaneQuery query;		
	}



	[Serializable]
	abstract public partial class esPaneCollection : esEntityCollection<Pane>
	{
		#region Housekeeping methods
		override protected IMetadata Meta
		{
			get
			{
				return PaneMetadata.Meta();
			}
		}

		protected override string GetCollectionName()
		{
			return "PaneCollection";
		}

		#endregion		
		
		#region Query Logic

	#if (!WindowsCE)
		[BrowsableAttribute(false)]
	#endif
		public PaneQuery Query
		{
			get
			{
				if (this.query == null)
				{
					this.query = new PaneQuery();
					InitQuery(this.query);
				}

				return this.query;
			}
		}

		public bool Load(PaneQuery query)
		{
			this.query = query;
			InitQuery(this.query);
			return Query.Load();
		}

		override protected esDynamicQuery GetDynamicQuery()
		{
			if (this.query == null)
			{
				this.query = new PaneQuery();
				this.InitQuery(query);
			}
			return this.query;
		}

		protected void InitQuery(PaneQuery query)
		{
			query.OnLoadDelegate = this.OnQueryLoaded;
			
			if (!query.es2.HasConnection)
			{
				query.es2.Connection = ((IEntityCollection)this).Connection;
			}			
		}

		protected override void HookupQuery(esDynamicQuery query)
		{
			this.InitQuery((PaneQuery)query);
		}

		#endregion
		
		private PaneQuery query;
	}



	[Serializable]
	abstract public partial class esPaneQuery : esDynamicQuery
	{
		override protected IMetadata Meta
		{
			get
			{
				return PaneMetadata.Meta();
			}
		}	
		
		#region QueryItemFromName
		
        protected override esQueryItem QueryItemFromName(string name)
        {
            switch (name)
            {
				case "Id": return this.Id;
				case "PortalID": return this.PortalID;
				case "ModuleID": return this.ModuleID;
				case "Title": return this.Title;
				case "Body": return this.Body;
				case "IsVisible": return this.IsVisible;
				case "DisplayOrder": return this.DisplayOrder;
				case "CreatedDate": return this.CreatedDate;
				case "ModifiedDate": return this.ModifiedDate;

                default: return null;
            }
        }		
		
		#endregion
		
		#region esQueryItems

		public esQueryItem Id
		{
			get { return new esQueryItem(this, PaneMetadata.ColumnNames.Id, esSystemType.Int32); }
		} 
		
		public esQueryItem PortalID
		{
			get { return new esQueryItem(this, PaneMetadata.ColumnNames.PortalID, esSystemType.Int32); }
		} 
		
		public esQueryItem ModuleID
		{
			get { return new esQueryItem(this, PaneMetadata.ColumnNames.ModuleID, esSystemType.Int32); }
		} 
		
		public esQueryItem Title
		{
			get { return new esQueryItem(this, PaneMetadata.ColumnNames.Title, esSystemType.String); }
		} 
		
		public esQueryItem Body
		{
			get { return new esQueryItem(this, PaneMetadata.ColumnNames.Body, esSystemType.String); }
		} 
		
		public esQueryItem IsVisible
		{
			get { return new esQueryItem(this, PaneMetadata.ColumnNames.IsVisible, esSystemType.Boolean); }
		} 
		
		public esQueryItem DisplayOrder
		{
			get { return new esQueryItem(this, PaneMetadata.ColumnNames.DisplayOrder, esSystemType.Int32); }
		} 
		
		public esQueryItem CreatedDate
		{
			get { return new esQueryItem(this, PaneMetadata.ColumnNames.CreatedDate, esSystemType.DateTime); }
		} 
		
		public esQueryItem ModifiedDate
		{
			get { return new esQueryItem(this, PaneMetadata.ColumnNames.ModifiedDate, esSystemType.DateTime); }
		} 
		
		#endregion
		
	}


	
	public partial class Pane : esPane
	{

		
		
	}
	



	[Serializable]
	public partial class PaneMetadata : esMetadata, IMetadata
	{
		#region Protected Constructor
		protected PaneMetadata()
		{
			m_columns = new esColumnMetadataCollection();
			esColumnMetadata c;

			c = new esColumnMetadata(PaneMetadata.ColumnNames.Id, 0, typeof(System.Int32), esSystemType.Int32);
			c.PropertyName = PaneMetadata.PropertyNames.Id;
			c.IsInPrimaryKey = true;
			c.IsAutoIncrement = true;
			c.NumericPrecision = 10;
			m_columns.Add(c);
				
			c = new esColumnMetadata(PaneMetadata.ColumnNames.PortalID, 1, typeof(System.Int32), esSystemType.Int32);
			c.PropertyName = PaneMetadata.PropertyNames.PortalID;
			c.NumericPrecision = 10;
			c.IsNullable = true;
			m_columns.Add(c);
				
			c = new esColumnMetadata(PaneMetadata.ColumnNames.ModuleID, 2, typeof(System.Int32), esSystemType.Int32);
			c.PropertyName = PaneMetadata.PropertyNames.ModuleID;
			c.NumericPrecision = 10;
			c.IsNullable = true;
			m_columns.Add(c);
				
			c = new esColumnMetadata(PaneMetadata.ColumnNames.Title, 3, typeof(System.String), esSystemType.String);
			c.PropertyName = PaneMetadata.PropertyNames.Title;
			c.CharacterMaxLength = 50;
			c.IsNullable = true;
			m_columns.Add(c);
				
			c = new esColumnMetadata(PaneMetadata.ColumnNames.Body, 4, typeof(System.String), esSystemType.String);
			c.PropertyName = PaneMetadata.PropertyNames.Body;
			c.CharacterMaxLength = 1073741823;
			c.IsNullable = true;
			m_columns.Add(c);
				
			c = new esColumnMetadata(PaneMetadata.ColumnNames.IsVisible, 5, typeof(System.Boolean), esSystemType.Boolean);
			c.PropertyName = PaneMetadata.PropertyNames.IsVisible;
			c.IsNullable = true;
			m_columns.Add(c);
				
			c = new esColumnMetadata(PaneMetadata.ColumnNames.DisplayOrder, 6, typeof(System.Int32), esSystemType.Int32);
			c.PropertyName = PaneMetadata.PropertyNames.DisplayOrder;
			c.NumericPrecision = 10;
			c.IsNullable = true;
			m_columns.Add(c);
				
			c = new esColumnMetadata(PaneMetadata.ColumnNames.CreatedDate, 7, typeof(System.DateTime), esSystemType.DateTime);
			c.PropertyName = PaneMetadata.PropertyNames.CreatedDate;
			c.HasDefault = true;
			c.Default = @"(getdate())";
			c.IsNullable = true;
			m_columns.Add(c);
				
			c = new esColumnMetadata(PaneMetadata.ColumnNames.ModifiedDate, 8, typeof(System.DateTime), esSystemType.DateTime);
			c.PropertyName = PaneMetadata.PropertyNames.ModifiedDate;
			c.IsNullable = true;
			m_columns.Add(c);
				
		}
		#endregion	
	
		static public PaneMetadata Meta()
		{
			return meta;
		}	
		
		public Guid DataID
		{
			get { return base.m_dataID; }
		}	
		
		public bool MultiProviderMode
		{
			get { return false; }
		}		

		public esColumnMetadataCollection Columns
		{
			get	{ return base.m_columns; }
		}
		
		#region ColumnNames
		public class ColumnNames
		{ 
			 public const string Id = "ID";
			 public const string PortalID = "PortalID";
			 public const string ModuleID = "ModuleID";
			 public const string Title = "Title";
			 public const string Body = "Body";
			 public const string IsVisible = "IsVisible";
			 public const string DisplayOrder = "DisplayOrder";
			 public const string CreatedDate = "CreatedDate";
			 public const string ModifiedDate = "ModifiedDate";
		}
		#endregion	
		
		#region PropertyNames
		public class PropertyNames
		{ 
			 public const string Id = "Id";
			 public const string PortalID = "PortalID";
			 public const string ModuleID = "ModuleID";
			 public const string Title = "Title";
			 public const string Body = "Body";
			 public const string IsVisible = "IsVisible";
			 public const string DisplayOrder = "DisplayOrder";
			 public const string CreatedDate = "CreatedDate";
			 public const string ModifiedDate = "ModifiedDate";
		}
		#endregion	

		public esProviderSpecificMetadata GetProviderMetadata(string mapName)
		{
			MapToMeta mapMethod = mapDelegates[mapName];

			if (mapMethod != null)
				return mapMethod(mapName);
			else
				return null;
		}
		
		#region MAP esDefault
		
		static private int RegisterDelegateesDefault()
		{
			// This is only executed once per the life of the application
			lock (typeof(PaneMetadata))
			{
				if(PaneMetadata.mapDelegates == null)
				{
					PaneMetadata.mapDelegates = new Dictionary<string,MapToMeta>();
				}
				
				if (PaneMetadata.meta == null)
				{
					PaneMetadata.meta = new PaneMetadata();
				}
				
				MapToMeta mapMethod = new MapToMeta(meta.esDefault);
				mapDelegates.Add("esDefault", mapMethod);
				mapMethod("esDefault");
			}
			return 0;
		}			

		private esProviderSpecificMetadata esDefault(string mapName)
		{
			if(!m_providerMetadataMaps.ContainsKey(mapName))
			{
				esProviderSpecificMetadata meta = new esProviderSpecificMetadata();			


				meta.AddTypeMap("Id", new esTypeMap("int", "System.Int32"));
				meta.AddTypeMap("PortalID", new esTypeMap("int", "System.Int32"));
				meta.AddTypeMap("ModuleID", new esTypeMap("int", "System.Int32"));
				meta.AddTypeMap("Title", new esTypeMap("nvarchar", "System.String"));
				meta.AddTypeMap("Body", new esTypeMap("nvarchar", "System.String"));
				meta.AddTypeMap("IsVisible", new esTypeMap("bit", "System.Boolean"));
				meta.AddTypeMap("DisplayOrder", new esTypeMap("int", "System.Int32"));
				meta.AddTypeMap("CreatedDate", new esTypeMap("datetime", "System.DateTime"));
				meta.AddTypeMap("ModifiedDate", new esTypeMap("datetime", "System.DateTime"));			
				
				
				
				ProviderConfiguration providerConfiguration = ProviderConfiguration.GetProviderConfiguration("data");
				Provider provider = (Provider)providerConfiguration.Providers[providerConfiguration.DefaultProvider];

				string objectQualifier = provider.Attributes["objectQualifier"];

				if ((objectQualifier != string.Empty) && (objectQualifier.EndsWith("_") == false))
				{
					objectQualifier += "_";
				}

				if (objectQualifier != string.Empty)
				{
					meta.Source = objectQualifier + "DNNspot_Tabs_Panes";
					meta.Destination = objectQualifier + "DNNspot_Tabs_Panes";
					
					meta.spInsert = objectQualifier + "proc_DNNspot_Tabs_PanesInsert";				
					meta.spUpdate = objectQualifier + "proc_DNNspot_Tabs_PanesUpdate";		
					meta.spDelete = objectQualifier + "proc_DNNspot_Tabs_PanesDelete";
					meta.spLoadAll = objectQualifier + "proc_DNNspot_Tabs_PanesLoadAll";
					meta.spLoadByPrimaryKey = objectQualifier + "proc_DNNspot_Tabs_PanesLoadByPrimaryKey";
				}
				else
				{
					meta.Source = "DNNspot_Tabs_Panes";
					meta.Destination = "DNNspot_Tabs_Panes";
									
					meta.spInsert = "proc_DNNspot_Tabs_PanesInsert";				
					meta.spUpdate = "proc_DNNspot_Tabs_PanesUpdate";		
					meta.spDelete = "proc_DNNspot_Tabs_PanesDelete";
					meta.spLoadAll = "proc_DNNspot_Tabs_PanesLoadAll";
					meta.spLoadByPrimaryKey = "proc_DNNspot_Tabs_PanesLoadByPrimaryKey";
				}
				
				
				this.m_providerMetadataMaps["esDefault"] = meta;
			}
			
			return this.m_providerMetadataMaps["esDefault"];
		}

		#endregion

		static private PaneMetadata meta;
		static protected Dictionary<string, MapToMeta> mapDelegates;
		static private int _esDefault = RegisterDelegateesDefault();
	}
}
