﻿/*
* This software is licensed under the GNU General Public License, version 2
* You may copy, distribute and modify the software as long as you track changes/dates of in source files and keep all modifications under GPL. You can distribute your application using a GPL library commercially, but you must also provide the source code.

* DNNspot Software (http://www.dnnspot.com)
* Copyright (C) 2013 Atriage Software LLC
* Authors: Kevin Southworth, Matthew Hall, Ryan Doom

* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.

* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.

* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

* Full license viewable here: http://www.gnu.org/licenses/gpl-2.0.txt
*/

using System;
using DNNspot.Tabs.Common;
using DNNspot.Tabs.DataModel;

namespace DNNspot.Tabs
{
    public partial class EditPane : ModuleBase
    {
        #region Members

        private int? _paneId;
        protected DotNetNuke.UI.UserControls.TextEditor txtBody;

        #endregion

        #region Events

        protected void btnCancel_Click(object sender, EventArgs e)
        {
            Response.Redirect(EditUrl(ControlKeys.ListPanes));
        }

        protected void btnDelete_Click(object sender, EventArgs e)
        {
            DestroyPane(_paneId);
            Response.Redirect(EditUrl(ControlKeys.ListPanes));
        }

        protected void btnSave_Click(object sender, EventArgs e)
        {
            SavePane(_paneId);
            Response.Redirect(EditUrl(ControlKeys.ListPanes));
        }

        protected new void Page_Init(object sender, EventArgs e)
        {
            base.Page_Init(sender, e);
            ModuleConfiguration.ModuleTitle = (Request.QueryString[RequestVariables.PaneId] == null ? "Add " : "Edit ") + ControlKeys.EditPane;
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            LoadMembers();

            if (!IsPostBack)
                PopulateControls();
        }

        #endregion

        #region Functions

        private static void DestroyPane(int? paneId)
        {
            var pane = new Pane();
            if (pane.LoadByPrimaryKey(Convert.ToInt32(paneId)))
            {
                pane.MarkAsDeleted();
                pane.Save();
            }
        }

        private int GetDisplayOrderMax()
        {
            var q = new PaneQuery();
            q.Select(q.DisplayOrder.Max());
            q.Where(q.PortalID == PortalId && q.ModuleID == ModuleId);

            object o = q.ExecuteScalar();

            return o.GetType() == typeof(DBNull) ? 0 : (int)o;
        }

        private void LoadMembers()
        {
            if (Request.QueryString[RequestVariables.PaneId] != null)
                _paneId = Convert.ToInt32(Request.QueryString[RequestVariables.PaneId]);
        }

        private void PopulateControls()
        {
            if (_paneId == null)
            {
                btnDelete.Visible = false;
                litSeparator.Visible = false;
            }
            else
            {
                var pane = new Pane();
                pane.LoadByPrimaryKey(Convert.ToInt32(_paneId));

                txtTitle.Text = pane.Title;
                txtBody.Text = pane.Body;
                chkVisible.Checked = Convert.ToBoolean(pane.IsVisible);
            }
        }

        private void SavePane(int? paneId)
        {
            var pane = new Pane();

            if (paneId == null)
            {
                int displayOrderMax = GetDisplayOrderMax();

                pane.PortalID = PortalId;
                pane.ModuleID = ModuleId;
                pane.DisplayOrder = displayOrderMax + 1;
                pane.CreatedDate = DateTime.Now;
            }
            else
            {
                pane.LoadByPrimaryKey(Convert.ToInt32(paneId));
            }

            pane.Title = txtTitle.Text;
            pane.Body = txtBody.Text;
            pane.IsVisible = chkVisible.Checked;
            pane.ModifiedDate = DateTime.Now;

            pane.Save();
        }

        #endregion
    }
}