﻿/*
* This software is licensed under the GNU General Public License, version 2
* You may copy, distribute and modify the software as long as you track changes/dates of in source files and keep all modifications under GPL. You can distribute your application using a GPL library commercially, but you must also provide the source code.

* DNNspot Software (http://www.dnnspot.com)
* Copyright (C) 2013 Atriage Software LLC
* Authors: Kevin Southworth, Matthew Hall, Ryan Doom

* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.

* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.

* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

* Full license viewable here: http://www.gnu.org/licenses/gpl-2.0.txt
*/

using System;
using System.Collections.Generic;
using System.Web.UI.WebControls;
using DotNetNuke.Common;
using DotNetNuke.Entities.Modules;
using DotNetNuke.Entities.Modules.Actions;
using DotNetNuke.Security;
using DNNspot.Tabs.Common;
using DNNspot.Tabs.DataModel;

namespace DNNspot.Tabs
{
    public partial class ListPanes : ModuleBase, IActionable
    {
        #region Members

        private int _displayOrderMax;
        private int _displayOrderMin;

        #endregion

        #region Properties

        public ModuleActionCollection ModuleActions
        {
            get
            {
                var actions = new ModuleActionCollection();

                actions.Add(
                    GetNextActionID(),
                    "Back",
                    ModuleActionType.AddContent,
                    "",
                    "",
                    Globals.NavigateURL(TabId),
                    false,
                    SecurityAccessLevel.Edit,
                    true,
                    false);

                actions.Add(
                    GetNextActionID(),
                    "Add Pane",
                    ModuleActionType.AddContent,
                    "",
                    "",
                    EditUrl(ControlKeys.EditPane),
                    false,
                    SecurityAccessLevel.Edit,
                    true,
                    false);


                return actions;
            }
        }

        #endregion

        #region Events

        protected void btnDelete_Command(object sender, CommandEventArgs e)
        {
            var btnDelete = (ImageButton) sender;
            var row = (RepeaterItem) btnDelete.Parent;
            var hidPaneId = (HiddenField) row.FindControl("hidPaneId");

            var pane = new Pane();
            if (pane.LoadByPrimaryKey(Convert.ToInt32(hidPaneId.Value)))
            {
                pane.MarkAsDeleted();
                pane.Save();
            }

            BindPanes();
        }

        protected void btnDown_Command(object sender, CommandEventArgs e)
        {
            var btnDown = (ImageButton) sender;
            var row = (RepeaterItem) btnDown.Parent;
            var hidPaneId = (HiddenField)row.FindControl("hidPaneId");

            DemotePaneOrder(Convert.ToInt32(hidPaneId.Value));

            BindPanes();
        }

        protected void btnEdit_Command(object sender, CommandEventArgs e)
        {
            var btnEdit = (ImageButton) sender;
            var row = (RepeaterItem) btnEdit.Parent;
            var hidPaneId = (HiddenField)row.FindControl("hidPaneId");

            Response.Redirect(EditUrl("", "", ControlKeys.EditPane, new[] { String.Format("{0}={1}", RequestVariables.PaneId, hidPaneId.Value) }));
        }

        protected void btnUp_Command(object sender, CommandEventArgs e)
        {
            var btnUp = (ImageButton) sender;
            var row = (RepeaterItem) btnUp.Parent;
            var hidPaneId = (HiddenField)row.FindControl("hidPaneId");

            PromotePaneOrder(Convert.ToInt32(hidPaneId.Value));

            BindPanes();
        }

        protected new void Page_Init(object sender, EventArgs e)
        {
            base.Page_Init(sender, e);
            ModuleConfiguration.ModuleTitle = ControlKeys.ListPanes;
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            GetDisplayOrderBounds();

            if (!IsPostBack)
            {
                BindPanes();
            }
        }

        protected void rptPanes_ItemDataBound(object sender, RepeaterItemEventArgs e)
        {
            BindItem(e);
        }

        #endregion

        #region Functions

        private void BindItem(RepeaterItemEventArgs e)
        {
            if (e.Item.ItemType == ListItemType.Item || e.Item.ItemType == ListItemType.AlternatingItem)
            {
                var pane = (Pane) e.Item.DataItem;
                var hidPaneId = (HiddenField)e.Item.FindControl("hidPaneId");
                var litTitle = (Literal) e.Item.FindControl("litTitle");
                var btnUp = (ImageButton)e.Item.FindControl("btnUp");
                var btnDown = (ImageButton)e.Item.FindControl("btnDown");
                var btnEdit = (ImageButton)e.Item.FindControl("btnEdit");
                var btnDelete = (ImageButton)e.Item.FindControl("btnDelete");
                var imgSpacer = (Image)e.Item.FindControl("imgSpacer");

                btnUp.ImageUrl = String.Format("{0}{1}images/up.gif", Globals.ApplicationPath, ModuleWebPath);
                btnDown.ImageUrl = String.Format("{0}{1}images/down.gif", Globals.ApplicationPath, ModuleWebPath);
                btnEdit.ImageUrl = String.Format("{0}{1}images/edit.gif", Globals.ApplicationPath, ModuleWebPath);
                btnDelete.ImageUrl = String.Format("{0}{1}images/delete.gif", Globals.ApplicationPath, ModuleWebPath);
                imgSpacer.ImageUrl = String.Format("{0}{1}images/spacer.gif", Globals.ApplicationPath, ModuleWebPath);

                hidPaneId.Value = pane.Id.ToString();
                litTitle.Text = pane.Title;

                if (pane.DisplayOrder == _displayOrderMin)
                {
                    btnUp.Visible = false;
                }

                if (pane.DisplayOrder == _displayOrderMax)
                {
                    btnDown.Visible = false;
                    imgSpacer.Visible = true;
                }
            }
        }

        private void BindPanes()
        {
            GetDisplayOrderBounds();

            rptPanes.DataSource = GetAllModulePanes();
            rptPanes.DataBind();
        }

        private void DemotePaneOrder(int paneId)
        {
            var pane = new Pane();
            pane.LoadByPrimaryKey(paneId);

            var q = new PaneQuery();
            q.es.Top = 1;
            q.Where(q.PortalID == PortalId && q.ModuleID == ModuleId && q.DisplayOrder > pane.DisplayOrder);
            q.OrderBy(q.DisplayOrder.Ascending);

            var swap = new Pane();
            swap.Load(q);

            var swapDisplayOrder = swap.DisplayOrder;

            swap.DisplayOrder = pane.DisplayOrder;
            pane.DisplayOrder = swapDisplayOrder;

            pane.Save();
            swap.Save();
        }

        private IEnumerable<Pane> GetAllModulePanes()
        {
            var q = new PaneQuery();
            q.Where(q.PortalID == PortalId && q.ModuleID == ModuleId);
            q.OrderBy(q.DisplayOrder.Ascending);

            var panes = new PaneCollection();
            panes.Load(q);

            return panes;
        }

        private void GetDisplayOrderBounds()
        {
            var q = new PaneQuery();
            q.Select(q.DisplayOrder.Min());
            q.Where(q.PortalID == PortalId && q.ModuleID == ModuleId);

            object o = q.ExecuteScalar();

            _displayOrderMin = o.GetType() == typeof(DBNull) ? 0 : (int)o;

            q = new PaneQuery();
            q.Select(q.DisplayOrder.Max());
            q.Where(q.PortalID == PortalId && q.ModuleID == ModuleId);

            o = q.ExecuteScalar();

            _displayOrderMax = o.GetType() == typeof(DBNull) ? 0 : (int)o;
        }

        private void PromotePaneOrder(int paneId)
        {
            var pane = new Pane();
            pane.LoadByPrimaryKey(paneId);

            var q = new PaneQuery();
            q.es.Top = 1;
            q.Where(q.PortalID == PortalId && q.ModuleID == ModuleId && q.DisplayOrder < pane.DisplayOrder);
            q.OrderBy(q.DisplayOrder.Descending);

            var swap = new Pane();
            swap.Load(q);

            var swapDisplayOrder = swap.DisplayOrder;

            swap.DisplayOrder = pane.DisplayOrder;
            pane.DisplayOrder = swapDisplayOrder;

            pane.Save();
            swap.Save();
        }

        #endregion
    }
}